==> jobimtext_pipeline_0.0.5.tar.gz: jobimtext_pipeline_0.0.5/generateHadoopScriptOthers.py <==
import pprint
import sys 

def printPig(cls, params,comment=False):
	p = " -param "
	out="pig "+p+p.join(params)+" pig/"+cls+".pig"
	if comment: out="#"+out
	print out
	
def printHadoop(cls,inp, outp, compress, param="",comment=False):
	tmp = " ".join([param,inp,outp, str(compress)])
	out ="hadoop jar lib/thesaurus.distributional.hadoop-0.0.5.jar jobimtext.thesaurus.distributional.hadoop.mapreduce."+cls+tmp
	if comment: out="#"+out 
	print out
def bylength(word1,word2):
    return len(word1)-len(word2)

def removeOutputfolders():
	l = globals()
	folders = []
	for name in l.keys():
		if(name.endswith("_out")):
			folders.append(name+"\t"+ l[name])

	folders.sort(cmp=bylength)
	for f in folders:
		print("#hadoop dfs -rmr "+f)
		#print(f)

if(len(sys.argv)<7):
	print "This script can be generated to calculate Lin's and Curran's measure for fixed relations (e.g. for ngrams)
	print "Parameters needed: dataset s t p significance simsort_count [computer file_prefix]"
	print "dataset: e.g. news10M_ngram_1_3, news10M_maltparser"
	print "s: number"
	print "t: number"
	print "p: number"
	print "significance: LMI, PMI, LL"
	print "simsort count - number of similar terms sorted in the last step" 
	print "optional parameter:"
	print "computer: computer to copy the files to"
	print "file_prefix: prefix, the files (distributional similarity, WordCount, FeatureCount) will be copied to"
	sys.exit()
	

clsContext ="WordFeatureCount"
clsWordCount = "WordCount"
clsFeatureCount = "FeatureCount"
clsFreqSig = "FreqSig"
clsPrunegraph = "PruneGraph"
clsAggregate="AggrPerFt"
clsSimCount="SimCounts1WithFeatures"
clsSimSort="SimSort"




dataset="news1k_parses"
s = 10
t = 10
p = 500

dataset = sys.argv[1]
s  = sys.argv[2]
t  = sys.argv[3]
p  = sys.argv[4]
significance  = sys.argv[5]
simsort_limit = sys.argv[6]


clsFreqSig = clsFreqSig+significance
fileHandle = open("others_"+dataset+"_s"+str(s)+"_t"+str(t)+"_p"+str(p)+"_"+significance+"_simsort"+simsort_limit+".sh", 'w')
sys.stdout = fileHandle

context_out = dataset+"__"+clsContext
wordcount_out = dataset+"__"+clsWordCount
featurecount_out = dataset+"__"+clsFeatureCount
freqsig_p=[]
freqsig_p.append("s="+str(s))
freqsig_p.append("t="+str(t))
freqsig_out = dataset+"__"+clsFreqSig+"_"+"_".join(freqsig_p).replace("=","_")
freqsig_p.append("wordcountout="+wordcount_out)
freqsig_p.append("featurecountout="+featurecount_out)
freqsig_p.append("contextout="+context_out)
freqsig_p.append("freqsigout="+freqsig_out)
prunegraph_p=[]
prunegraph_p.append("p="+str(p))
prunegraph_out = freqsig_out+"__"+clsPrunegraph+"_"+"_".join(prunegraph_p).replace("=","_")
prunegraph_p.append("freqsigout="+freqsig_out)
prunegraph_p.append("prunegraphout="+prunegraph_out)
aggregate_out=prunegraph_out+"__"+clsAggregate
simcount_p=[]
simcount_out=aggregate_out+"__"+clsSimCount+"_".join(simcount_p).replace("=","_")

simsort_out=simcount_out+"__"+clsSimSort
simsort_p=[]
simsort_p.append("limit="+simsort_limit)
simsort_out=simcount_out+"__"+clsSimSort+"_".join(simsort_p).replace("=","_")
simsort_p.append("IN="+simcount_out)
simsort_p.append("OUT="+simsort_out)


#removeOutputfolders()

#printHadoop(clsContext,dataset,context_out,True)
#printHadoop(clsFeatureCount,context_out,featurecount_out,True)
#printHadoop(clsWordCount,context_out,wordcount_out,True)
#printPig(clsFreqSig,freqsig_p)
#printPig(clsPrunegraph,prunegraph_p)
#printHadoop(clsAggregate,prunegraph_out,aggregate_out,True)
#printHadoop(clsSimCount,aggregate_out,simcount_out,True)
#printPig(clsSimSort,simsort_p)


clsWordFeatureRelationCount="WordFeatureRelationCount"
clsWordRelationCount = "WordRelationCount"
clsRelationCount = "RelationCount"

relationcount_out = dataset+"__"+clsRelationCount
wordrelationcount_out = dataset+"__"+clsWordRelationCount
wordfeaturerelationcount_out = dataset+"__"+clsWordFeatureRelationCount
clsWeightLin="WeightLin98A"
weight_lin_out=dataset+"__"+clsWeightLin
weight_lin_sum_out=dataset+"__"+clsWeightLin+"Sum"
weight_lin_p=[]
weight_lin_p.append("fc="+featurecount_out)
weight_lin_p.append("wfrc="+wordfeaturerelationcount_out)
weight_lin_p.append("wc="+wordcount_out)
weight_lin_p.append("rc="+relationcount_out)
weight_lin_p.append("fc="+featurecount_out)
weight_lin_p.append("wrc="+wordrelationcount_out)
weight_lin_p.append("out="+weight_lin_out)
weight_lin_p.append("sum_out="+weight_lin_sum_out)

clsWeightTTest="WeightTTest"
weight_ttest_out = dataset+"__"+clsWeightTTest
weight_ttest_p=[]
weight_ttest_p.append("fc="+featurecount_out)
weight_ttest_p.append("wfc="+context_out)
weight_ttest_p.append("wc="+wordcount_out)
weight_ttest_p.append("out="+weight_ttest_out)

clsSimLin= "SimilarityLin"
simlin_out = simsort_out+"__"+clsSimLin
simlin_p=[]
simlin_p.append("weight_lin="+weight_lin_out)
simlin_p.append("weight_lin_sum="+weight_lin_sum_out)
simlin_p.append("sim="+simsort_out)
simlin_p.append("out="+simlin_out)

clsSimDice="SimilarityDice"
simdice_out=simsort_out+"__"+clsSimDice
simdice_p=[]
simdice_p.append("sim="+simsort_out)
simdice_p.append("wfc="+context_out)
simdice_p.append("weight="+weight_ttest_out)
simdice_p.append("out="+simdice_out)

clsSimSort="SimSort"
simdicesort_p=[]
simdicesort_p.append("limit="+simsort_limit)
simdicesort_out=simdice_out+"__"+clsSimSort+"_".join(simsort_p).replace("=","_")
simdicesort_p.append("IN="+simdice_out)
simdicesort_p.append("OUT="+simdicesort_out)

simlinsort_p=[]
simlinsort_p.append("limit="+simsort_limit)
simlinsort_out=simlin_out+"__"+clsSimSort+"_".join(simsort_p).replace("=","_")
simlinsort_p.append("IN="+simlin_out)
simlinsort_p.append("OUT="+simlinsort_out)


printHadoop(clsWordFeatureRelationCount, context_out,wordfeaturerelationcount_out, True)
printHadoop(clsWordRelationCount, context_out,wordrelationcount_out, True)
printHadoop(clsRelationCount, context_out,relationcount_out, True)
printPig(clsWeightLin, weight_lin_p)
printPig(clsSimLin,simlin_p)

printPig(clsWeightTTest,weight_ttest_p)
printPig(clsSimDice,simdice_p)

printPig(clsSimSort, simdicesort_p)
printPig(clsSimSort, simlinsort_p)

==> jobimtext_pipeline_0.0.6.tar.gz: jobimtext_pipeline_0.0.6/generateHadoopScriptOthers.py <==
import pprint
import sys 

def printPig(cls, params,comment=False):
	p = " -param "
	out="pig "+p+p.join(params)+" pig/"+cls+".pig"
	if comment: out="#"+out
	print out
	
def printHadoop(cls,inp, outp, compress, param="",comment=False):
	tmp = " ".join([param,inp,outp, str(compress)])
	out ="hadoop jar lib/thesaurus.distributional.hadoop-0.0.6.jar jobimtext.thesaurus.distributional.hadoop.mapreduce."+cls+tmp
	if comment: out="#"+out 
	print out
def bylength(word1,word2):
    return len(word1)-len(word2)

def removeOutputfolders():
	l = globals()
	folders = []
	for name in l.keys():
		if(name.endswith("_out")):
			folders.append(name+"\t"+ l[name])

	folders.sort(cmp=bylength)
	for f in folders:
		print("#hadoop dfs -rmr "+f)
		#print(f)

if(len(sys.argv)<8):
	print "Parameters needed: dataset s t p significance simsort_count [computer file_prefix]"
	print "dataset: e.g. news10M_ngram_1_3, news10M_maltparser"
	print "wc: maximal number of uniq words a feature is allowed to have" 
	print "s: lower threshold for significance score"
	print "t: lower threshold for word count "
	print "p: maximal number of features a word is allowed to have"
	print "significance: LMI, PMI, LL"
	print "simsort count - number of similar terms sorted in the last step" 
	print "optional parameter:"
	print "computer: computer to copy the files to"
	print "file_prefix: prefix, the files (distributional similarity, WordCount, FeatureCount) will be copied to"
	sys.exit()
	

clsContext ="WordFeatureCount"
clsWordCount = "WordCount"
clsFeatureCount = "FeatureCount"
clsFreqSig = "FreqSig"
clsPrunegraph = "PruneGraph"
clsAggregate="AggrPerFt"
clsSimCount="SimCounts1WithFeatures"
clsSimSort="SimSort"




dataset="news1k_parses"
s = 10
t = 10
p = 500

dataset = sys.argv[1]
s  = sys.argv[2]
t  = sys.argv[3]
p  = sys.argv[4]
significance  = sys.argv[5]
simsort_limit = sys.argv[6]


clsFreqSig = clsFreqSig+significance
fileHandle = open("others_"+dataset+"_s"+str(s)+"_t"+str(t)+"_p"+str(p)+"_"+significance+"_simsort"+simsort_limit+".sh", 'w')
sys.stdout = fileHandle

context_out = dataset+"__"+clsContext
wordcount_out = dataset+"__"+clsWordCount
featurecount_out = dataset+"__"+clsFeatureCount
freqsig_p=[]
freqsig_p.append("s="+str(s))
freqsig_p.append("t="+str(t))
freqsig_out = dataset+"__"+clsFreqSig+"_"+"_".join(freqsig_p).replace("=","_")
freqsig_p.append("wordcountout="+wordcount_out)
freqsig_p.append("featurecountout="+featurecount_out)
freqsig_p.append("contextout="+context_out)
freqsig_p.append("freqsigout="+freqsig_out)
prunegraph_p=[]
prunegraph_p.append("p="+str(p))
prunegraph_out = freqsig_out+"__"+clsPrunegraph+"_"+"_".join(prunegraph_p).replace("=","_")
prunegraph_p.append("freqsigout="+freqsig_out)
prunegraph_p.append("prunegraphout="+prunegraph_out)
aggregate_out=prunegraph_out+"__"+clsAggregate
simcount_p=[]
simcount_out=aggregate_out+"__"+clsSimCount+"_".join(simcount_p).replace("=","_")

simsort_out=simcount_out+"__"+clsSimSort
simsort_p=[]
simsort_p.append("limit="+simsort_limit)
simsort_out=simcount_out+"__"+clsSimSort+"_".join(simsort_p).replace("=","_")
simsort_p.append("IN="+simcount_out)
simsort_p.append("OUT="+simsort_out)


#removeOutputfolders()

#printHadoop(clsContext,dataset,context_out,True)
printHadoop(clsFeatureCount,context_out,featurecount_out,True)
printHadoop(clsWordCount,context_out,wordcount_out,True)
#printPig(clsFreqSig,freqsig_p)
#printPig(clsPrunegraph,prunegraph_p)
#printHadoop(clsAggregate,prunegraph_out,aggregate_out,True)
#printHadoop(clsSimCount,aggregate_out,simcount_out,True)
#printPig(clsSimSort,simsort_p)


clsWordFeatureRelationCount="WordFeatureRelationCount"
clsWordRelationCount = "WordRelationCount"
clsRelationCount = "RelationCount"

relationcount_out = dataset+"__"+clsRelationCount
wordrelationcount_out = dataset+"__"+clsWordRelationCount
wordfeaturerelationcount_out = dataset+"__"+clsWordFeatureRelationCount
clsWeightLin="WeightLin98A"
weight_lin_out=dataset+"__"+clsWeightLin
weight_lin_sum_out=dataset+"__"+clsWeightLin+"Sum"
weight_lin_p=[]
weight_lin_p.append("fc="+featurecount_out)
weight_lin_p.append("wfrc="+wordfeaturerelationcount_out)
weight_lin_p.append("wc="+wordcount_out)
weight_lin_p.append("rc="+relationcount_out)
weight_lin_p.append("fc="+featurecount_out)
weight_lin_p.append("wrc="+wordrelationcount_out)
weight_lin_p.append("out="+weight_lin_out)
weight_lin_p.append("sum_out="+weight_lin_sum_out)

clsWeightTTest="WeightTTest"
weight_ttest_out = dataset+"__"+clsWeightTTest
weight_ttest_p=[]
weight_ttest_p.append("fc="+featurecount_out)
weight_ttest_p.append("wfc="+context_out)
weight_ttest_p.append("wc="+wordcount_out)
weight_ttest_p.append("out="+weight_ttest_out)

clsSimLin= "SimilarityLin"
simlin_out = simsort_out+"__"+clsSimLin
simlin_p=[]
simlin_p.append("weight_lin="+weight_lin_out)
simlin_p.append("weight_lin_sum="+weight_lin_sum_out)
simlin_p.append("sim="+simsort_out)
simlin_p.append("out="+simlin_out)

clsSimDice="SimilarityDice"
simdice_out=simsort_out+"__"+clsSimDice
simdice_p=[]
simdice_p.append("sim="+simsort_out)
simdice_p.append("wfc="+context_out)
simdice_p.append("weight="+weight_ttest_out)
simdice_p.append("out="+simdice_out)

clsSimSort="SimSort"
simdicesort_p=[]
simdicesort_p.append("limit="+simsort_limit)
simdicesort_out=simdice_out+"__"+clsSimSort+"_".join(simsort_p).replace("=","_")
simdicesort_p.append("IN="+simdice_out)
simdicesort_p.append("OUT="+simdicesort_out)

simlinsort_p=[]
simlinsort_p.append("limit="+simsort_limit)
simlinsort_out=simlin_out+"__"+clsSimSort+"_".join(simsort_p).replace("=","_")
simlinsort_p.append("IN="+simlin_out)
simlinsort_p.append("OUT="+simlinsort_out)


printHadoop(clsWordFeatureRelationCount, context_out,wordfeaturerelationcount_out, True)
printHadoop(clsWordRelationCount, context_out,wordrelationcount_out, True)
printHadoop(clsRelationCount, context_out,relationcount_out, True)
printPig(clsWeightLin, weight_lin_p)
printPig(clsSimLin,simlin_p)

printPig(clsWeightTTest,weight_ttest_p)
printPig(clsSimDice,simdice_p)

printPig(clsSimSort, simdicesort_p)
printPig(clsSimSort, simlinsort_p)
